@@ -1,21 +1,9 @@
 /*
- * Copyright © 2018 Red Hat, Inc
+ * SPDX-FileCopyrightText: 2018 Red Hat Inc
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *       Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2018 Jan Grulich <jgrulich@redhat.com>
  */
 
 #include "screenchooserdialog.h"
@@ -23,28 +11,31 @@
 #include "waylandintegration.h"
 
 #include <KLocalizedString>
+#include <KWayland/Client/plasmawindowmanagement.h>
+#include <KWayland/Client/plasmawindowmodel.h>
 #include <QPushButton>
-#include <QStandardPaths>
 #include <QSettings>
 #include <QSortFilterProxyModel>
-#include <KWayland/Client/plasmawindowmodel.h>
-#include <KWayland/Client/plasmawindowmanagement.h>
+#include <QStandardPaths>
 
 class FilteredWindowModel : public QSortFilterProxyModel
 {
 public:
-    FilteredWindowModel(QObject* parent) : QSortFilterProxyModel(parent)
-    {}
+    FilteredWindowModel(QObject *parent)
+        : QSortFilterProxyModel(parent)
+    {
+    }
 
-    bool filterAcceptsRow(int source_row, const QModelIndex & source_parent) const override {
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override
+    {
         if (source_parent.isValid())
             return false;
 
         const auto idx = sourceModel()->index(source_row, 0);
         using KWayland::Client::PlasmaWindowModel;
 
-        return !idx.data(PlasmaWindowModel::SkipTaskbar).toBool()
-            && !idx.data(PlasmaWindowModel::SkipSwitcher).toBool()
+        return !idx.data(PlasmaWindowModel::SkipTaskbar).toBool() //
+            && !idx.data(PlasmaWindowModel::SkipSwitcher).toBool() //
             && idx.data(PlasmaWindowModel::Pid) != QCoreApplication::applicationPid();
     }
 };
@@ -115,8 +106,7 @@ void ScreenChooserDialog::selectionChanged(const QItemSelection &selected)
     }
 
     auto okButton = m_dialog->buttonBox->button(QDialogButtonBox::Ok);
-    const auto count = m_dialog->screenView->selectionModel()->hasSelection()
-                     + m_dialog->windowsView->selectionModel()->hasSelection();
+    const auto count = m_dialog->screenView->selectionModel()->hasSelection() + m_dialog->windowsView->selectionModel()->hasSelection();
     okButton->setEnabled(m_multiple ? count > 0 : count == 1);
 }
 
